/*
 Tecnisa - Tecnologia em Informtica

 Nome: Exclui contas exportadas

 Descrio:
 Procedimento para excluso de todas as contas ligadas  nota fiscal, boletos referentes as contas,
   baixas e movimentos bancarios

 Criao:
 27/04/2002 - Andr Rodrigo

 Chamada para criao
 @C:\Win_Prj\Sql\Oracle\1007_PAGSTP_EXCLUI_CONTAPAG_EXPORTADA.SQL;

 */

CREATE OR REPLACE PROCEDURE EXCLUI_CONTAPAG_EXPORTADA
   (P_CDFILIAL    IN NOTAFISCAL.CDFILIAL%TYPE,
    P_NRLANCTONF  IN NOTAFISCAL.NRLANCTONF%TYPE)

AS
   V_CDREDUBX     BAIXAPAGA.CDREDUCONT%TYPE;
   V_NRMOVBANC    BAIXAPAGA.NRMOVBANC%TYPE;
   V_CDSEQUEXBA   MOVBANCARIO.CDSEQUEXBA%TYPE;
   V_NRSEQMOVREBA MOVBANCARIO.NRSEQMOVREBA%TYPE;
   V_CDFILIBAIPAG BOLETPAGAR.CDFILIAL%TYPE;
   V_NRBAIXAPAG   BOLETPAGAR.NRBAIXAPAG%TYPE;

   V_VRAJBOLPAG NUMBER;
   V_VRAJUCTPAG NUMBER;
   V_CTDEL      NUMBER;
BEGIN
   FOR C_CNTPAG IN (SELECT CDFILIAL,     NRLANCTONF,  NRSEQVENPAG,
                           CDFILIBPAG,   NRLANBOLPAG, CDEMPRESA,
                           CDFIMOVFLPAG, DTMOVFLUXO,  IDMOVFLUXO,
                           CDCLASSFINA,  VRORIGPAG,   NRPARCELAPAG
                    FROM CONTAPAGAR
                    WHERE CDFILIAL   = P_CDFILIAL AND
                          NRLANCTONF = P_NRLANCTONF
                    ORDER BY NRSEQVENPAG) LOOP

      SELECT MAX(BP.CDFILIBAIPAG), MAX(BP.NRBAIXAPAG)
      INTO V_CDFILIBAIPAG, V_NRBAIXAPAG
      FROM BOLETPAGAR BP, CONTAPAGAR CP
      WHERE
         (CP.CDFILIAL     = C_CNTPAG.CDFILIAL)     AND
         (CP.NRLANCTONF   = C_CNTPAG.NRLANCTONF)   AND
         (CP.NRSEQVENPAG  = C_CNTPAG.NRSEQVENPAG)  AND
         (CP.NRPARCELAPAG = C_CNTPAG.NRPARCELAPAG) AND
         (CP.CDFILIBPAG   = BP.CDFILIAL)           AND
         (CP.NRLANBOLPAG  = BP.NRLANBOLPAG);

      /* BUSCA TODOS OS BOLETOS LIGADOS A BAIXA  */
      FOR C_BOLETPAG_BX IN (SELECT CDFILIAL, NRLANBOLPAG, CDFILIBAIPAG, NRBAIXAPAG
                            FROM BOLETPAGAR
                            WHERE (CDFILIBAIPAG = V_CDFILIBAIPAG) AND
                                  (NRBAIXAPAG   = V_NRBAIXAPAG)) LOOP

         FOR C_RATR IN (SELECT AJ.CDFILIAL,     AJ.NRLANBOLPAG, AJ.CDAJUCTPAG,
                               AJ.VRAJBOLPAG,   CR.CDCLASSFINA, CR.CDEMPRESA,
                               CR.CDFIMOVFLPAG, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                               TA.IDAJUCTPAG,   CR.IDSTATPAG,
                               DECODE(MAX(BR.VRBOLPAG), 0, 0,
                                     (MAX(AJ.VRAJBOLPAG) * SUM(CR.VRATUAPAG))/ MAX(BR.VRBOLPAG)) VRRATAJBOLPAG
                        FROM CONTAPAGAR  CR, BOLETPAGAR BR,
                             TIPOAJPAGAR TA, AJBOLPAG   AJ
                        WHERE (AJ.CDFILIAL     = C_BOLETPAG_BX.CDFILIAL)    AND
                              (AJ.NRLANBOLPAG  = C_BOLETPAG_BX.NRLANBOLPAG) AND
                              (TA.CDAJUCTPAG   = AJ.CDAJUCTPAG)          AND
                              (BR.CDFILIAL     = AJ.CDFILIAL)            AND
                              (BR.NRLANBOLPAG  = AJ.NRLANBOLPAG)         AND
                              (CR.CDFILIBPAG = BR.CDFILIAL)            AND
                              (CR.NRLANBOLPAG  = BR.NRLANBOLPAG)
                        GROUP BY
                           AJ.CDFILIAL,     AJ.NRLANBOLPAG, AJ.CDAJUCTPAG,
                           AJ.VRAJBOLPAG,   CR.CDCLASSFINA, CR.CDEMPRESA,
                           CR.CDFIMOVFLPAG, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                           TA.IDAJUCTPAG,   CR.IDSTATPAG) LOOP

            IF C_RATR.IDAJUCTPAG = 'D' THEN
               V_VRAJBOLPAG := ROUND(C_RATR.VRRATAJBOLPAG, 2);
            ELSE
               V_VRAJBOLPAG := ROUND(C_RATR.VRRATAJBOLPAG * -1, 2);
            END IF;
            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_RATR.CDEMPRESA,   C_RATR.CDFIMOVFLPAG,
                                    C_RATR.DTMOVFLUXO,  C_RATR.IDMOVFLUXO,
                                    C_RATR.CDCLASSFINA, 0, V_VRAJBOLPAG);

            DELETE FROM MOVFXAJBOLP
            WHERE CDFILIBOLPAG = C_BOLETPAG_BX.CDFILIAL    AND
                  NRLANBOLPAG  = C_BOLETPAG_BX.NRLANBOLPAG AND
                  CDAJUCTPAG   = C_RATR.CDAJUCTPAG;
         END LOOP;

         DELETE FROM AJBOLPAG
         WHERE CDFILIAL    = C_BOLETPAG_BX.CDFILIAL AND
               NRLANBOLPAG = C_BOLETPAG_BX.NRLANBOLPAG;

         FOR C_CNTPAG_BX IN (SELECT CDFILIAL,     NRLANCTONF,  NRSEQVENPAG,
                                    CDFILIBPAG, NRLANBOLPAG, CDEMPRESA,
                                    CDFIMOVFLPAG, DTMOVFLUXO,  IDMOVFLUXO,
                                    CDCLASSFINA,  VRORIGPAG,   NRPARCELAPAG
                             FROM CONTAPAGAR
                             WHERE CDFILIBPAG  = C_BOLETPAG_BX.CDFILIAL AND
                                   NRLANBOLPAG = C_BOLETPAG_BX.NRLANBOLPAG
                             ORDER BY NRSEQVENPAG) LOOP

            FOR C_AJCTPAG IN (SELECT AJ.CDFILIAL,    AJ.NRLANCTONF,   AJ.CDAJUCTPAG,
                                     AJ.CDCLASSFINA, AJ.CDEMMFAJCNTP, AJ.CDFIMFAJCNTP,
                                     AJ.DTMOVFLUXO,  AJ.IDMOVFLUXO,   AJ.VRAJUSTEPAG,
                                     TA.IDAJUCTPAG,  AJ.NRSEQVENPAG,  AJ.NRPARCELAPAG
                              FROM AJCTPAGAR AJ, TIPOAJPAGAR TA
                              WHERE (AJ.CDFILIAL     = C_CNTPAG_BX.CDFILIAL)     AND
                                    (AJ.NRLANCTONF   = C_CNTPAG_BX.NRLANCTONF)   AND
                                    (AJ.NRSEQVENPAG  = C_CNTPAG_BX.NRSEQVENPAG)  AND
                                    (AJ.NRPARCELAPAG = C_CNTPAG_BX.NRPARCELAPAG) AND
                                    (TA.CDAJUCTPAG   = AJ.CDAJUCTPAG)) LOOP

               IF C_AJCTPAG.IDAJUCTPAG = 'D' THEN
                  V_VRAJUCTPAG := ROUND(C_AJCTPAG.VRAJUSTEPAG, 2);
               ELSE
                  V_VRAJUCTPAG := ROUND(C_AJCTPAG.VRAJUSTEPAG * -1, 2);
               END IF;
               /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
               ATUALIZA_FLUXO_DE_CAIXA(C_AJCTPAG.CDEMMFAJCNTP, C_AJCTPAG.CDFIMFAJCNTP,
                                       C_AJCTPAG.DTMOVFLUXO,   C_AJCTPAG.IDMOVFLUXO,
                                       C_AJCTPAG.CDCLASSFINA,  0, V_VRAJUCTPAG);

               DELETE FROM AJCTPAGAR
               WHERE (CDFILIAL     = C_AJCTPAG.CDFILIAL)     AND
                     (NRLANCTONF   = C_AJCTPAG.NRLANCTONF)   AND
                     (NRSEQVENPAG  = C_AJCTPAG.NRSEQVENPAG)  AND
                     (NRPARCELAPAG = C_AJCTPAG.NRPARCELAPAG);
            END LOOP;

            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_CNTPAG_BX.CDEMPRESA,   C_CNTPAG_BX.CDFIMOVFLPAG,
                                    C_CNTPAG_BX.DTMOVFLUXO,  C_CNTPAG_BX.IDMOVFLUXO,
                                    C_CNTPAG_BX.CDCLASSFINA, 0, C_CNTPAG_BX.VRORIGPAG * -1);
            DELETE FROM CONTAPAGAR
            WHERE (CDFILIAL     = C_CNTPAG_BX.CDFILIAL)     AND
                  (NRLANCTONF   = C_CNTPAG_BX.NRLANCTONF)   AND
                  (NRSEQVENPAG  = C_CNTPAG_BX.NRSEQVENPAG)  AND
                  (NRPARCELAPAG = C_CNTPAG_BX.NRPARCELAPAG);
         END LOOP;

         DELETE FROM BOLETPAGAR
         WHERE CDFILIAL    = C_BOLETPAG_BX.CDFILIAL AND
               NRLANBOLPAG = C_BOLETPAG_BX.NRLANBOLPAG;

         DBMS_OUTPUT.PUT_LINE('DEL BOLETPAGAR');
      END LOOP;

      SELECT MAX(BX.CDREDUCONT), MAX(BX.NRMOVBANC), COUNT(*)
      INTO V_CDREDUBX, V_NRMOVBANC, V_CTDEL
      FROM BAIXAPAGA BX
      WHERE
         (BX.CDFILIAL   = V_CDFILIBAIPAG) AND
         (BX.NRBAIXAPAG = V_NRBAIXAPAG);

      V_CDSEQUEXBA   := '';
      V_NRSEQMOVREBA := '';
      IF NOT V_NRMOVBANC IS NULL THEN
         SELECT MAX(CDSEQUEXBA), MAX(NRSEQMOVREBA)
         INTO V_CDSEQUEXBA, V_NRSEQMOVREBA
         FROM MOVBANCARIO
         WHERE
            (CDREDUCONT = V_CDREDUBX) AND
            (NRMOVBANC  = V_NRMOVBANC);
      END IF;

      IF V_CTDEL > 0 THEN
         DELETE FROM BAIXAPAGA
         WHERE
            (CDFILIAL   = V_CDFILIBAIPAG) AND
            (NRBAIXAPAG = V_NRBAIXAPAG);
      END IF;

      DBMS_OUTPUT.PUT_LINE('DEL BAIXAPAGA');

      IF NOT V_CDSEQUEXBA IS NULL THEN
         UPDATE MOVBANCARIO
         SET
            IDSTCONEXT   = 0,
            IDCONCBANC   = NULL,
            CDSEQUEXBA   = NULL,
            NRSEQMOVREBA = NULL
         WHERE
            (CDREDUCONT   = V_CDREDUBX)   AND
            (IDSTCONEXT   = '1')          AND
            (CDSEQUEXBA   = V_CDSEQUEXBA) AND
            (NRSEQMOVREBA = V_NRSEQMOVREBA);
      END IF;

      IF NOT V_NRMOVBANC IS NULL THEN
         DELETE FROM MOVBANCARIO
         WHERE
            (CDREDUCONT = V_CDREDUBX) AND
            (NRMOVBANC  = V_NRMOVBANC);
      END IF;

      IF NOT V_CDSEQUEXBA IS NULL THEN
         UPDATE MOVREAL
         SET
            IDSTCONMVBAN = 0,
            IDCONCREAL   = NULL,
            NRMOVBARE    = NULL
         WHERE
            (CDREDUCONT   = V_CDREDUBX) AND
            (CDSEQUEXTR   = V_CDSEQUEXBA) AND
            (NRSEQMOVREAL = V_NRSEQMOVREBA);
      END IF;

      /* BUSCA TODAS OS BOLETOS QUE NO ESTO LIGADOS A BAIXA  */
      FOR C_BOLETREC_AB IN (SELECT CDFILIAL,     NRLANCTONF,  NRSEQVENPAG,
                                   CDFILIBPAG, NRLANBOLPAG, CDEMPRESA,
                                   CDFIMOVFLPAG, DTMOVFLUXO,  IDMOVFLUXO,
                                   CDCLASSFINA,  VRORIGPAG,   NRPARCELAPAG
                            FROM CONTAPAGAR
                            WHERE (CDFILIBPAG   = C_CNTPAG.CDFILIBPAG) AND
                                  (NRLANBOLPAG  = C_CNTPAG.NRLANBOLPAG)
                            ORDER BY NRSEQVENPAG) LOOP

         FOR C_RATR IN (SELECT AJ.CDFILIAL,     AJ.NRLANBOLPAG, AJ.CDAJUCTPAG,
                               AJ.VRAJBOLPAG,   CR.CDCLASSFINA, CR.CDEMPRESA,
                               CR.CDFIMOVFLPAG, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                               TA.IDAJUCTPAG,   CR.IDSTATPAG,
                               DECODE(MAX(BR.VRBOLPAG), 0, 0,
                                     (MAX(AJ.VRAJBOLPAG) * SUM(CR.VRATUAPAG))/ MAX(BR.VRBOLPAG)) VRRATAJBOLPAG
                        FROM CONTAPAGAR  CR, BOLETPAGAR BR,
                             TIPOAJPAGAR TA, AJBOLPAG   AJ
                        WHERE (AJ.CDFILIAL     = C_BOLETREC_AB.CDFILIBPAG)  AND
                              (AJ.NRLANBOLPAG  = C_BOLETREC_AB.NRLANBOLPAG) AND
                              (TA.CDAJUCTPAG   = AJ.CDAJUCTPAG)         AND
                              (BR.CDFILIAL     = AJ.CDFILIAL)           AND
                              (BR.NRLANBOLPAG  = AJ.NRLANBOLPAG)        AND
                              (CR.CDFILIBPAG   = BR.CDFILIAL)           AND
                              (CR.NRLANBOLPAG  = BR.NRLANBOLPAG)
                        GROUP BY
                           AJ.CDFILIAL,     AJ.NRLANBOLPAG, AJ.CDAJUCTPAG,
                           AJ.VRAJBOLPAG,   CR.CDCLASSFINA, CR.CDEMPRESA,
                           CR.CDFIMOVFLPAG, CR.DTMOVFLUXO,  CR.IDMOVFLUXO,
                           TA.IDAJUCTPAG,   CR.IDSTATPAG) LOOP

            IF C_RATR.IDAJUCTPAG = 'D' THEN
               V_VRAJBOLPAG := ROUND(C_RATR.VRRATAJBOLPAG, 2);
            ELSE
               V_VRAJBOLPAG := ROUND(C_RATR.VRRATAJBOLPAG * -1, 2);
            END IF;
            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_RATR.CDEMPRESA,   C_RATR.CDFIMOVFLPAG,
                                    C_RATR.DTMOVFLUXO,  C_RATR.IDMOVFLUXO,
                                    C_RATR.CDCLASSFINA, 0, V_VRAJBOLPAG);

            DELETE FROM MOVFXAJBOLP
            WHERE CDFILIBOLPAG = C_BOLETREC_AB.CDFILIBPAG  AND
                  NRLANBOLPAG  = C_BOLETREC_AB.NRLANBOLPAG AND
                  CDAJUCTPAG   = C_RATR.CDAJUCTPAG;
         END LOOP;

         FOR C_AJCTPAG IN (SELECT AJ.CDFILIAL,    AJ.NRLANCTONF,   AJ.CDAJUCTPAG,
                                  AJ.CDCLASSFINA, AJ.CDEMMFAJCNTP, AJ.CDFIMFAJCNTP,
                                  AJ.DTMOVFLUXO,  AJ.IDMOVFLUXO,   AJ.VRAJUSTEPAG,
                                  TA.IDAJUCTPAG,  AJ.NRSEQVENPAG,  AJ.NRPARCELAPAG
                           FROM AJCTPAGAR AJ, TIPOAJPAGAR TA
                           WHERE (AJ.CDFILIAL     = C_BOLETREC_AB.CDFILIAL)     AND
                                 (AJ.NRLANCTONF   = C_BOLETREC_AB.NRLANCTONF)   AND
                                 (AJ.NRSEQVENPAG  = C_BOLETREC_AB.NRSEQVENPAG)  AND
                                 (AJ.NRPARCELAPAG = C_BOLETREC_AB.NRPARCELAPAG) AND
                                 (TA.CDAJUCTPAG   = AJ.CDAJUCTPAG)) LOOP

            IF C_AJCTPAG.IDAJUCTPAG = 'D' THEN
               V_VRAJUCTPAG := ROUND(C_AJCTPAG.VRAJUSTEPAG, 2);
            ELSE
               V_VRAJUCTPAG := ROUND(C_AJCTPAG.VRAJUSTEPAG * -1, 2);
            END IF;
            /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
            ATUALIZA_FLUXO_DE_CAIXA(C_AJCTPAG.CDEMMFAJCNTP, C_AJCTPAG.CDFIMFAJCNTP,
                                    C_AJCTPAG.DTMOVFLUXO,   C_AJCTPAG.IDMOVFLUXO,
                                    C_AJCTPAG.CDCLASSFINA,  0, V_VRAJUCTPAG);

            DELETE FROM AJCTPAGAR
            WHERE
               (CDFILIAL     = C_AJCTPAG.CDFILIAL)     AND
               (NRLANCTONF   = C_AJCTPAG.NRLANCTONF)   AND
               (NRSEQVENPAG  = C_AJCTPAG.NRSEQVENPAG)  AND
               (NRPARCELAPAG = C_AJCTPAG.NRPARCELAPAG);
         END LOOP;

         /* - DESFAZ O FLUXO DE CAIXA -------------------------- */
         ATUALIZA_FLUXO_DE_CAIXA(C_BOLETREC_AB.CDEMPRESA,   C_BOLETREC_AB.CDFIMOVFLPAG,
                                 C_BOLETREC_AB.DTMOVFLUXO,  C_BOLETREC_AB.IDMOVFLUXO,
                                 C_BOLETREC_AB.CDCLASSFINA, 0, C_BOLETREC_AB.VRORIGPAG * -1);
         DELETE FROM CONTAPAGAR
         WHERE CDFILIBPAG  = C_BOLETREC_AB.CDFILIBPAG AND
               NRLANBOLPAG = C_BOLETREC_AB.NRLANBOLPAG;

      END LOOP;

      DELETE FROM AJBOLPAG
      WHERE CDFILIAL    = C_CNTPAG.CDFILIBPAG AND
            NRLANBOLPAG = C_CNTPAG.NRLANBOLPAG;

      DELETE FROM BOLETPAGAR
      WHERE CDFILIAL    = C_CNTPAG.CDFILIBPAG AND
            NRLANBOLPAG = C_CNTPAG.NRLANBOLPAG;
   END LOOP;
END;
/

